@@ -19,15 +19,16 @@
 //
 
 using System;
+using LongoMatch.Video.Handlers;
 
 namespace LongoMatch.Video.Capturer
 {
 	
 	
 	public interface ICapturer
-	{
-		
-		
+	{	
+		event EllpasedTimeHandler EllapsedTime;
+			
 		uint EncodeWidth {
 			get ;
 			set ;
@@ -42,7 +43,6 @@ namespace LongoMatch.Video.Capturer
 			get ;
 			set ;
 		}
-
 				
 		uint VideoBitrate {
 			get;
@@ -53,8 +53,15 @@ namespace LongoMatch.Video.Capturer
 			get ;
 			set ;
 		}
+		
+		int CurrentTime {
+			get ;
+		}
+		
 		bool SetVideoEncoder(LongoMatch.Video.Capturer.GccVideoEncoderType type);
+		
 		bool SetAudioEncoder(LongoMatch.Video.Capturer.GccAudioEncoderType type);
+		
 		bool SetVideoMuxer(LongoMatch.Video.Capturer.GccVideoMuxerType type);
 		
 		void TogglePause();
@@ -62,7 +69,5 @@ namespace LongoMatch.Video.Capturer
 		void Start();
 		
 		void Stop();
-		
-		void Run();
 	}
 }
